@@ -1,5 +1,6 @@
 {-# LANGUAGE TypeFamilies
            , FlexibleContexts
+           , MultiParamTypeClasses
            , ViewPatterns
   #-}
 -----------------------------------------------------------------------------
@@ -19,11 +20,17 @@ module Diagrams.ThreeD.Shapes
        , sphere
        ) where
 
-import Graphics.Rendering.Diagrams
+import Prelude hiding (minimum)
+import Data.Semigroup
+
+import Data.AffineSpace
+import Data.Monoid.PosInf (minimum)
+import Data.VectorSpace
+
+import Diagrams.Core
 
 import Diagrams.ThreeD.Types
-
-import Data.Semigroup
+import Diagrams.Solve
 
 data Ellipsoid = Ellipsoid T3
 
@@ -32,10 +39,19 @@ type instance V Ellipsoid = R3
 instance Transformable Ellipsoid where
   transform t1 (Ellipsoid t2) = Ellipsoid (t1 <> t2)
 
+instance Renderable Ellipsoid NullBackend where
+  render _ _ = mempty
+
 sphere :: (Backend b R3, Renderable Ellipsoid b) => Diagram b R3
 sphere = mkQD (Prim $ Ellipsoid mempty)
               (mkEnvelope sphereEnv)
+              (mkTrace sphereTrace)
               mempty
               (Query sphereQuery)
-  where sphereEnv (unr3 -> (x,y,z))   = 1 / sqrt(x*x + y*y + z*z)
-        sphereQuery (unp3 -> (x,y,z)) = Any $ x*x + y*y + z*z <= 1
+  where sphereEnv v = 1 / magnitude v
+        sphereTrace p v = minimum (quadForm a b c)
+          where a = v <.> v
+                b = 2 *^ p' <.> v
+                c = p' <.> p' - 1
+                p' = p .-. origin
+        sphereQuery v = Any $ magnitudeSq (v .-. origin) <= 1
