@@ -87,6 +87,8 @@ module Diagrams.TwoD
        , ellipse
        , ellipseXY
        , arc
+       , arc'
+       , arcCW
        , wedge
 
          -- ** General polygons
@@ -147,14 +149,23 @@ module Diagrams.TwoD
        , shearingY, shearY
 
          -- * Combinators
+         -- ** Combining multiple diagrams
        , (===), (|||), atAngle
        , hcat, hcat'
        , vcat, vcat'
 
+         -- ** Spacing and envelopes
        , strutX, strutY
        , padX, padY
+
+       , extrudeLeft, extrudeRight, extrudeBottom, extrudeTop
+
        , view
 
+         -- ** Background
+
+       , boundingRect, bg
+
          -- * Alignment
        , alignL, alignR, alignT, alignB, alignTL, alignTR, alignBL, alignBR
        , alignX, alignY
@@ -162,13 +173,16 @@ module Diagrams.TwoD
 
          -- * Size
          -- ** Computing size
-       , width, height, size2D
+       , width, height, size2D, sizeSpec2D
        , extentX, extentY, center2D
 
          -- ** Specifying size
        , SizeSpec2D(..)
        , mkSizeSpec
 
+         -- ** Adjusting size
+       , sized, sizedAs
+
          -- * Visual aids for understanding the internal model
        , showOrigin
        , showOrigin'
