@@ -31,14 +31,16 @@ module Diagrams.TwoD.Text (
   , FontWeight(..), FontWeightA, getFontWeight, fontWeight, bold
   ) where
 
-import Graphics.Rendering.Diagrams
-
+import Diagrams.Attributes
+import Diagrams.Core
 import Diagrams.TwoD.Types
 
 import Data.AffineSpace ((.-.))
 
 import Data.Semigroup
 
+import Data.Colour
+
 import Data.Typeable
 
 ------------------------------------------------------------
@@ -66,23 +68,25 @@ instance Renderable Text NullBackend where
 data TextAlignment = BaselineText | BoxAlignedText Double Double
 
 mkText :: Renderable Text b => TextAlignment -> String -> Diagram b R2
-mkText a t = mkQD (Prim (Text mempty a t))
+mkText a t = recommendFillColor black
+           $ mkQD (Prim (Text mempty a t))
+                       mempty
                        mempty
                        mempty
                        mempty
 
 -- | Create a primitive text diagram from the given string, with center
---   alignment, equivalent to @alignedText 0.5 0.5@.
---    
+--   alignment, equivalent to @'alignedText' 0.5 0.5@.
+--
 --   Note that it /takes up no space/, as text size information is not
 --   available.
 text :: Renderable Text b => String -> Diagram b R2
 text = alignedText 0.5 0.5
 
 -- | Create a primitive text diagram from the given string, origin at
---   the top left corner of the text's bounding box, equivalent to 
---   @alignedText 0.5 0.5@.
---    
+--   the top left corner of the text's bounding box, equivalent to
+--   @'alignedText' 0 1@.
+--
 --   Note that it /takes up no space/.
 topLeftText :: Renderable Text b => String -> Diagram b R2
 topLeftText = alignedText 0 1
@@ -91,7 +95,7 @@ topLeftText = alignedText 0 1
 --   origin set to a point interpolated within the bounding box.  The
 --   first parameter varies from 0 (left) to 1 (right), and the second
 --   parameter from 0 (bottom) to 1 (top).
---   
+--
 --   The height of this box is determined by the font's potential ascent
 --   and descent, rather than the height of the particular string.
 --
@@ -103,7 +107,7 @@ alignedText w h = mkText (BoxAlignedText w h)
 --   origin set to be on the baseline, at the beginning (although not
 --   bounding).  This is the reference point of showText in the Cairo
 --   graphics library.
---   
+--
 --   Note that it /takes up no space/.
 baselineText :: Renderable Text b => String -> Diagram b R2
 baselineText = mkText BaselineText
@@ -118,7 +122,7 @@ baselineText = mkText BaselineText
 -- | The @Font@ attribute specifies the name of a font family.  Inner
 --   @Font@ attributes override outer ones.
 newtype Font = Font (Last String)
-  deriving (Typeable, Semigroup)
+  deriving (Typeable, Semigroup, Eq)
 instance AttributeClass Font
 
 -- | Extract the font family name from a @Font@ attribute.
@@ -136,7 +140,7 @@ font = applyAttr . Font . Last
 --   em-square, measured with respect to the current local vector space.
 --   Inner @FontSize@ attributes override outer ones.
 newtype FontSize = FontSize (Last Double)
-  deriving (Typeable, Semigroup)
+  deriving (Typeable, Semigroup, Eq)
 instance AttributeClass FontSize
 
 -- | Extract the size from a @FontSize@ attribute.
@@ -155,12 +159,13 @@ fontSize = applyAttr . FontSize . Last
 data FontSlant = FontSlantNormal
                | FontSlantItalic
                | FontSlantOblique
+    deriving (Eq)
 
 -- | The @FontSlantA@ attribute specifies the slant (normal, italic,
 --   or oblique) that should be used for all text within a diagram.
 --   Inner @FontSlantA@ attributes override outer ones.
 newtype FontSlantA = FontSlantA (Last FontSlant)
-  deriving (Typeable, Semigroup)
+  deriving (Typeable, Semigroup, Eq)
 instance AttributeClass FontSlantA
 
 -- | Extract the font slant from a 'FontSlantA' attribute.
@@ -186,12 +191,13 @@ oblique = fontSlant FontSlantOblique
 
 data FontWeight = FontWeightNormal
                 | FontWeightBold
+    deriving (Eq)
 
 -- | The @FontWeightA@ attribute specifies the weight (normal or bold)
 --   that should be used for all text within a diagram.  Inner
 --   @FontWeightA@ attributes override outer ones.
 newtype FontWeightA = FontWeightA (Last FontWeight)
-  deriving (Typeable, Semigroup)
+  deriving (Typeable, Semigroup, Eq)
 instance AttributeClass FontWeightA
 
 -- | Extract the font weight from a 'FontWeightA' attribute.
